@@ -14,6 +14,24 @@ pub enum ListView {
     Orderless(Box<OrderlessList>),
 }
 
+impl ListView {
+    #[inline]
+    pub fn children(&self) -> &Vec<ListItem> {
+        match self {
+            Self::Ordered(v) => &v.children,
+            Self::Orderless(v) => &v.children,
+        }
+    }
+    #[inline]
+    pub fn first_prefix(&self) -> Option<&ListPrefixSymbol> {
+        self.children().first().map(|f| &f.prefix.value)
+    }
+    #[inline]
+    pub fn is_ordered(&self) -> bool {
+        matches!(self, Self::Ordered(_))
+    }
+}
+
 impl ListView {
     /// ## Ordered List
     /// ```note
